@@ -19,17 +19,19 @@ class Config:
     PRODUCTION = os.getenv("PRODUCTION", False)
     USERNAME = os.getenv("MONGO_USERNAME")
     PASSWORD = os.getenv("MONGO_PASSWORD")
-    SERVER = os.getenv("MONGO_DATANATOR_SERVER")
+    SERVER = os.getenv("MONGO_DATANATOR_SERVER").split(',')
     PORT = os.getenv("MONGO_PORT")
     REPLSET = os.getenv("MONGO_REPL")
     AUTHDB = os.getenv("MONGO_AUTHDB")
     SESSION_KEY = os.getenv("FLASK_SESSION_KEY")
     READ_PREFERENCE = os.getenv("READ_PREFERENCE")
 
+
 class ProductionConfig(Config):
 
     PRODUCTION = True
 
+
 class TestConfig(Config):
     '''
         test user with read permission to 'datanator' and
@@ -39,6 +41,7 @@ class TestConfig(Config):
     MONGO_TEST_PASSWORD = os.getenv("MONGO_TEST_PASSWORD")
     MONGO_TEST_PASSWORD_READ_PREFERENCE = os.getenv("MONGO_TEST_PASSWORD_READ_PREFERENCE")
 
+
 class UserAccountConfig(Config):
     '''
         API user account manager with readWrite permission
@@ -50,6 +53,13 @@ class UserAccountConfig(Config):
     USERDAEMON_AUTHDB = os.getenv("MONGO_USER_AUTHDB")
 
 
+class FtxConfig(Config):
+    """Environment variables for AWS Elasticsearch service
+    """
+    FTX_AWS_PROFILE = os.getenv("FTX_AWS_PROFILE")
+    TEST_FTX_PROFILE_NAME = os.getenv("TEST_FTX_PROFILE_NAME")
+
+
 class FlaskProfiler(UserAccountConfig):
     '''
         API performance tracker with readWrite permission
